@@ -14,18 +14,28 @@ module KramdownRFC
       @f.delete(pn.to_s)
     end
     def []=(pn, val)
-      @f[pn] = val
+      @f[pn.to_s] = val
+    end
+    def default(pn, &block)
+      @f.fetch(pn.to_s, &block)
+    end
+    def default!(pn, value)
+      default(pn) {
+        @f[pn.to_s] = value
+      }
     end
     def has(pn)
       @f[pn.to_s]
     end
+    def has?(pn)
+      @f.key?(pn.to_s)
+    end
     def escattr(str)
       escape_html(str.to_s, :attribute)
     end
-    def van(pn)                   # pn is a parameter name, possibly with an =alias
-      an, pn = pn.to_s.split("=")
-      pn ||= an
-      [self[pn] || self[an], an]
+    def van(pn)         # pn is a parameter name, possibly with =aliases
+      names = pn.to_s.split("=")
+      [self[names.reverse.find{|nm| has?(nm)}], names.first]
     end
     def attr(pn)
       val, an = van(pn)
@@ -38,7 +48,19 @@ module KramdownRFC
     def ele(pn, attr=nil, defcontent=nil, markdown=false)
       val, an = van(pn)
       val ||= defcontent
+      val = [val] if Hash === val
       Array(val).map do |val1|
+        a = Array(attr).dup
+        if Hash === val1
+          val1.each do |k, v|
+            if k == ":"
+              val1 = v
+            else
+              k = Kramdown::Element.attrmangle(k) || k
+              a.unshift(%{#{k}="#{escattr(v)}"})
+            end
+          end
+        end
         v = val1.to_s.strip
         contents =
           if markdown
@@ -46,7 +68,7 @@ module KramdownRFC
           else
             escape_html(v)
           end
-        %{<#{[an, *Array(attr).map(&:to_s)].join(" ").strip}>#{contents}</#{an}>}
+        %{<#{[an, *a.map(&:to_s)].join(" ").strip}>#{contents}</#{an}>}
       end.join(" ")
     end
     def arr(an, converthash=true, must_have_one=false, &block)
