@@ -456,7 +456,7 @@ COLORS
 
       def memoize(meth, *args)
         require 'digest'
-        Dir.mkdir(REFCACHEDIR) unless Dir.exists?(REFCACHEDIR)
+        Dir.mkdir(REFCACHEDIR) unless Dir.exist?(REFCACHEDIR)
         kdrfc_version = Gem.loaded_specs["kramdown-rfc2629"].version.to_s.gsub('.', '_') rescue "UNKNOWN"
         fn = "#{REFCACHEDIR}/kdrfc-#{kdrfc_version}-#{meth}-#{Digest::SHA256.hexdigest(Marshal.dump(args))[0...40]}.cache"
         begin
@@ -506,6 +506,7 @@ COLORS
           elsif t == "protocol-aasvg"
             result1, err, _s = Open3.capture3("#{DEFAULT_AASVG}#{svg_opt}", stdin_data: result);
             dont_clean = true
+            dont_check = true
           else
             result1 = nil
           end
@@ -515,6 +516,7 @@ COLORS
         when "aasvg"
           result1, err, _s = Open3.capture3("#{DEFAULT_AASVG}#{svg_opt}", stdin_data: result);
           dont_clean = true
+          dont_check = true
         when "ditaa"        # XXX: This needs some form of option-setting
           result1, err, _s = Open3.capture3("ditaa #{file.path} --svg -o -#{svg_opt}", stdin_data: result);
         when "mscgen"
@@ -535,9 +537,20 @@ COLORS
           result, err, _s = Open3.capture3("kgt -l abnf -e rr#{t == "railroad" ? "text" : "utf8"}#{txt_opt}",
                                             stdin_data: result);
           err << err1.to_s
-        when "math"
+        when "math", "math-asciitex"
+          math = Shellwords.escape(result)
           result1, err, _s = Open3.capture3("tex2svg --font STIX --speech=false#{svg_opt} #{Shellwords.escape(' ' << result)}");
-          result, err1, _s = Open3.capture3("asciitex -f #{file.path}#{txt_opt}")
+          begin
+            raise Errno::ENOENT if t == "math-asciitex"
+            result, err1, s = Open3.capture3("utftex #{math}#{txt_opt}")
+            if s.exitstatus != 0
+              warn "** utftex: #{err1.inspect}"
+              raise Errno::ENOENT
+            end
+          rescue Errno::ENOENT
+            warn "** utftex not working, falling back to asciitex" unless t == "math-asciitex"
+            result, err1, _s = Open3.capture3("asciitex -f #{file.path}#{txt_opt}")
+          end
           err << err1
         end
         capture_croak(t, err)
@@ -607,7 +620,7 @@ COLORS
           end
           case t
           when "aasvg", "ditaa", "goat",
-               "math", "mermaid",  "mscgen",
+               "math", "math-asciitex", "mermaid",  "mscgen",
                "plantuml", "plantuml-utxt",
                "protocol", "protocol-aasvg", "protocol-goat",
                "railroad", "railroad-utf8"
@@ -712,6 +725,20 @@ COLORS
         [clean, irefs]
       end
 
+      def clean_pcdatav3(parts) # hack, will become unnecessary with v3 tables
+        clean = ''
+        parts.each do |p|
+          next if p.empty?
+          d = REXML::Document.new("<foo>#{p}</foo>")
+          t = REXML::XPath.each(d.root, "//text()").to_a.join
+          if t != p
+            warn "** simplified markup #{p.inspect} into #{t.inspect} in table heading"
+          end
+          clean << t
+        end
+        clean
+      end
+
       def convert_header(el, indent, opts)
         # todo: handle appendix tags
         el = el.deep_clone
@@ -890,8 +917,13 @@ COLORS
           end
         end
         if alignment
-          res, irefs = clean_pcdata(inner_a(el, indent, opts))
-          warn "*** lost markup #{irefs} in table heading" unless irefs.empty?
+          xmlres = inner_a(el, indent, opts)
+          if $options.v3
+            res = clean_pcdatav3(xmlres)
+          else
+            res, irefs = clean_pcdata(xmlres)
+            warn "*** lost markup #{irefs} in table heading" unless irefs.empty?
+          end
           "#{' '*indent}<ttcol #{widthopt}align='#{alignment}'#{el_html_attributes(el)}>#{res.empty? ? "&#160;" : res}</ttcol>\n" # XXX need clean_pcdata
         else
           res = inner(el, indent, opts)
@@ -1013,7 +1045,7 @@ COLORS
       # this is now slightly dangerous as multiple urls could map to the same cachefile
       def get_and_cache_resource(url, cachefile, tvalid = 7200, tn = Time.now)
         fn = "#{REFCACHEDIR}/#{cachefile}"
-        Dir.mkdir(REFCACHEDIR) unless Dir.exists?(REFCACHEDIR)
+        Dir.mkdir(REFCACHEDIR) unless Dir.exist?(REFCACHEDIR)
         f = File.stat(fn) rescue nil unless KRAMDOWN_REFCACHE_REFETCH
         if !KRAMDOWN_OFFLINE && (!f || tn - f.mtime >= tvalid)
           if f
@@ -1107,7 +1139,7 @@ COLORS
         "NIST" => "bibxml2",
         "OASIS" => "bibxml2",
         "PKCS" => "bibxml2",
-        "DOI" => ["bibxml7", 86400, true, ->(fn, n){ [fn, [:DOI, n] ] }
+        "DOI" => ["bibxml7", 86400, true, ->(fn, n){ ["computed-#{fn}", [:DOI, n] ] }, true # always_altproc
                  ], # emulate old 24 h cache
         "IANA" => ["bibxml8", 86400, true], # ditto
       }
@@ -1122,6 +1154,7 @@ COLORS
       KRAMDOWN_REFCACHETTL = (e = ENV["KRAMDOWN_REFCACHETTL"]) ? e.to_i : 3600
 
       KRAMDOWN_NO_TARGETS = ENV['KRAMDOWN_NO_TARGETS']
+      KRAMDOWN_KEEP_TARGETS = ENV['KRAMDOWN_KEEP_TARGETS']
 
       def convert_img(el, indent, opts) # misuse the tag!
         if a = el.attr
@@ -1141,14 +1174,16 @@ COLORS
           anchor.gsub!('/', '_')              # should take out all illegals
           to_insert = ""
           src.scan(/(W3C|3GPP|[A-Z-]+)[.]?([A-Za-z_0-9.\(\)\/\+-]+)/) do |t, n|
+            never_altproc = n.sub!(/^[.]/, "")
             fn = "reference.#{t}.#{n}.xml"
-            sub, ttl, _can_anchor, altproc = XML_RESOURCE_ORG_MAP[t]
+            sub, ttl, _can_anchor, altproc, always_altproc = XML_RESOURCE_ORG_MAP[t]
             ttl ||= KRAMDOWN_REFCACHETTL  # everything but RFCs might change a lot
             puts "*** Huh: #{fn}" unless sub
-            if altproc && !KRAMDOWN_USE_TOOLS_SERVER
+            if altproc && !never_altproc && (!KRAMDOWN_USE_TOOLS_SERVER || always_altproc)
               fn, url = altproc.call(fn, n)
             else
               url = "#{XML_RESOURCE_ORG_PREFIX}/#{sub}/#{fn}"
+              fn = "alt-#{fn}" if never_altproc || KRAMDOWN_USE_TOOLS_SERVER
             end
             # if can_anchor # create anchor server-side for stand_alone: false
             #   url << "?anchor=#{anchor}"
@@ -1160,9 +1195,10 @@ COLORS
             begin
               d = REXML::Document.new(to_insert)
               d.xml_decl.nowrite
+              d.delete d.doctype
               d.root.attributes["anchor"] = anchor
               if t == "RFC" or t == "I-D"
-                if KRAMDOWN_NO_TARGETS
+                if KRAMDOWN_NO_TARGETS || !KRAMDOWN_KEEP_TARGETS
                   d.root.attributes["target"] = nil
                   REXML::XPath.each(d.root, "/reference/format") { |x|
                     d.root.delete_element(x)
@@ -1385,9 +1421,9 @@ COLORS
         end
         iref ||= "<iref#{html_attributes(item: item, subitem: subitem)}/>"
         if target
-          "<xref#{html_attributes(target: target, format: "none")}>#{value}</xref>#{iref}"
+          "#{iref}<xref#{html_attributes(target: target, format: "none")}>#{value}</xref>"
         else
-          "#{value}#{iref}"
+          "#{iref}#{value}"
         end
       end
 
